@@ -105,31 +105,37 @@ class GuppyWindow:
 		                                    cwd=getConfValue('PVR_CWD'),
 		                                    show_parent_dir=show_parent_dir)
 		
-		self.pc_path_entry_box = self.glade_xml.get_widget('pc_path_entry_box')
-		self.pvr_path_entry_box = self.glade_xml.get_widget('pvr_path_entry_box')
+		self.pc_path = {}
+		self.pc_path['entry_box'] = self.glade_xml.get_widget('pc_path_entry_box')
 		
-		self.pc_path_bar = None
-		self.pvr_path_bar = None
+		self.pvr_path = {}
+		self.pvr_path['entry_box'] = self.glade_xml.get_widget('pvr_path_entry_box')
+		
+		self.pc_path['bar'] = None
+		self.pvr_path['bar'] = None
 		if self.no_path_bar_support:
-			self.pc_path_entry_box.show()
-			self.pvr_path_entry_box.show()
+			self.pc_path['entry_box'].show()
+			self.pvr_path['entry_box'].show()
 		else:
-			self.pvr_path_bar = PathBar(self, 'pvr')
-			self.pvr_path_bar.set_border_width(3)
+			self.pvr_path['bar'] = PathBar(self, 'pvr')
+			self.pvr_path['bar'].set_border_width(3)
 			
-			self.pc_path_bar = PathBar(self, 'pc')
-			self.pc_path_bar.set_border_width(3)
+			self.pc_path['bar'] = PathBar(self, 'pc')
+			self.pc_path['bar'].set_border_width(3)
 			
 			pvr_vbox = self.glade_xml.get_widget('pvr_path_vbox')
-			pvr_vbox.pack_start(self.pvr_path_bar, expand=True, fill=True)
-			self.pvr_path_bar.show_all()		
+			pvr_vbox.pack_start(self.pvr_path['bar'], expand=True, fill=True)
+			self.pvr_path['bar'].show_all()		
 	
 			pc_vbox = self.glade_xml.get_widget('pc_path_vbox')
-			pc_vbox.pack_start(self.pc_path_bar, expand=True, fill=True)
-			self.pc_path_bar.show_all()
+			pc_vbox.pack_start(self.pc_path['bar'], expand=True, fill=True)
+			self.pc_path['bar'].show_all()
 	
 			self.updatePathBar(self.pvr_model)
 			self.updatePathBar(self.pc_model)
+
+		actions['goto_pc_dir'].connect('activate', self.on_goto_dir, self.pc_path, self.pc_model)
+		actions['goto_pvr_dir'].connect('activate', self.on_goto_dir, self.pvr_path, self.pvr_model)
 		
 		# Timer to update screen info
 		gobject.timeout_add(GuppyWindow.SCREEN_INFO_UPDATE_INTERVAL, self.updateScreenInfo)
@@ -169,14 +175,19 @@ class GuppyWindow:
 		                         ('View', None, _('_View')),
 		                         ('Transfer', None, _('_Transfer')),
 		                         ('Help', None, _('_Help')),
-                                 ('About', gtk.STOCK_ABOUT , _('_About'), None, None, self.on_about)])
-
-		actiongroup.add_actions([('GotoPCDir', None, _('Goto PC Location'), '<Ctrl>l', None, self.on_goto_pc_dir),
-		                         ('GotoPVRDir', None, _('Goto PVR Location'), '<Ctrl>k', None, self.on_goto_pvr_dir),
+		                         ('About', gtk.STOCK_ABOUT , _('_About'), None, None, self.on_about),
 		                         ('Reload', gtk.STOCK_REFRESH, _('Reload folders'), '<Ctrl>r', None, self.on_reload_dir)])
-			                         
+
+		action = gtk.Action('GotoPVRDir', _('Go to PVR Location'), _('Go to PVR Location'), None)
+		actiongroup.add_action_with_accel(action, '<Ctrl>k')
+		actions['goto_pvr_dir'] = action
+		
+		action = gtk.Action('GotoPCDir', _('Go to PC Location'), _('Go to PC Location'), None)
+		actiongroup.add_action_with_accel(action, '<Ctrl>l')
+		actions['goto_pc_dir'] = action
+		
 		actiongroup.add_toggle_actions([('QuitAfterTransfer', None, _('Quit After Transfer'), None, None, self.on_quit_after_transfer),
-		                                ('ShowHidden', None, _('Show Hidden Files'), None, _('Show hidden files'), self.on_show_hidden_toggled),
+		                                ('ShowHidden', None, _('Show Hidden Files'), None, _('Show Hidden Files'), self.on_show_hidden_toggled),
 		                                ('ShowFileTransfer', None, _('Show File Transfer'), None, _('Show File Transfer'), self.on_show_file_transfer_toggled)])
 
 		turbo_act = gtk.ToggleAction('Turbo', _('Tur_bo'), _('Turbo Transfer'), None)
@@ -252,14 +263,16 @@ class GuppyWindow:
 		pc_liststore = gtk.TreeModelSort(pc_liststore)
 		self.pc_liststore = pc_liststore
 		
-		self.pvr_path_entry = self.glade_xml.get_widget('pvr_path_entry')
-		self.pc_path_entry = self.glade_xml.get_widget('pc_path_entry')
+		self.pvr_path['entry'] = self.glade_xml.get_widget('pvr_path_entry')
+		self.pvr_path['entry'].connect('activate', self.on_path_entry_activate, self.pvr_model)
+		self.pvr_path['entry'].connect('key-press-event', self.on_path_entry_key_press, self.pvr_path)
 		
-		self.pvr_path_entry.connect('activate', self.on_path_entry_activate, self.pvr_model)
-		self.pc_path_entry.connect('activate', self.on_path_entry_activate, self.pc_model)
+		self.pc_path['entry'] = self.glade_xml.get_widget('pc_path_entry')
+		self.pc_path['entry'].connect('activate', self.on_path_entry_activate, self.pc_model)
+		self.pc_path['entry'].connect('key-press-event', self.on_path_entry_key_press, self.pc_path)
 		
-		self.pvr_path_entry.set_text(self.pvr_model.getCWD())
-		self.pc_path_entry.set_text(self.pc_model.getCWD())
+		self.pvr_path['entry'].set_text(self.pvr_model.getCWD())
+		self.pc_path['entry'].set_text(self.pc_model.getCWD())
 		
 		for treeview, liststore in (self.pvr_treeview, pvr_liststore), (self.pc_treeview, pc_liststore):
 			treeview.set_model(liststore)
@@ -339,30 +352,32 @@ class GuppyWindow:
 		toolbar.set_orientation(gtk.ORIENTATION_VERTICAL)
 		return toolbar
 
-	def deleteFiles(self, files, fs_model):
+	def deleteFiles(self, files, fs_model, warn=True):
 		"""Delete files from file system. Popup error dialog for errors.
 	
 		Return: True if all files deleted.
 		"""
-		msg = '<b>' + _('Are you sure you want to permanently delete') + '\n'
 		
-		files_len =  len(files)
-		if files_len > 1:
-			msg += ' ' + _('the') + ' ' + str(files_len) + ' ' + _('selected items?')
-		else:
-			msg += ' "' + files[0] + '"?'
+		if warn:
+			msg = '<b>' + _('Are you sure you want to permanently delete') + '\n'
 			
-		msg += '</b>\n\n' + _('If you delete an item, it is permanently lost.')
-		
-		dialog = gtk.MessageDialog(type=gtk.MESSAGE_QUESTION, buttons=gtk.BUTTONS_CANCEL)
-		dialog.set_markup(msg)
-		dialog.add_button(gtk.STOCK_DELETE, 0)
-		
-		response = dialog.run()
-		dialog.destroy()
-
-		if response == gtk.RESPONSE_CANCEL or response == gtk.RESPONSE_DELETE_EVENT:
-			return False
+			files_len =  len(files)
+			if files_len > 1:
+				msg += ' ' + _('the %d selected items?') % files_len
+			else:
+				msg += ' "' + files[0] + '"?'
+				
+			msg += '</b>\n\n' + _('If you delete an item, it is permanently lost.')
+			
+			dialog = gtk.MessageDialog(type=gtk.MESSAGE_QUESTION, buttons=gtk.BUTTONS_CANCEL)
+			dialog.set_markup(msg)
+			dialog.add_button(gtk.STOCK_DELETE, 0)
+			
+			response = dialog.run()
+			dialog.destroy()
+	
+			if response == gtk.RESPONSE_CANCEL or response == gtk.RESPONSE_DELETE_EVENT:
+				return False
 		
 		retval = True
 		for name in files:
@@ -378,7 +393,7 @@ class GuppyWindow:
 					msg += _('because you do not have permissions to change it or its parent folder.')
 					dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR)
 					dialog.set_markup(msg)
-					dialog.add_buttons( _('Skip'), SKIP, _('Retry'), RETRY)
+					dialog.add_buttons( _('_Skip'), SKIP, _('_Retry'), RETRY)
 					response = dialog.run()
 					dialog.destroy()
 		
@@ -400,6 +415,13 @@ class GuppyWindow:
 		self.updateTreeViews(fs_model, True)
 		self.updateFreeSpace(fs_model)
 		
+		if isinstance(fs_model, PCFileSystemModel):
+			path_bar = self.pc_path['bar']
+		else:
+			path_bar = self.pvr_path['bar']
+			
+		path_bar.setPath(fs_model.getCWD(), update_btns=False)
+		
 		return retval
 	
 	def hiddenFileFilter(self, model, iter, data=None):
@@ -415,10 +437,9 @@ class GuppyWindow:
 		if not self.puppy.exists():
 			dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR,
 			                           buttons=gtk.BUTTONS_OK)
-			dialog.set_markup(_('''Guppy can not run because the program Puppy is not available. Please install Puppy.
-
-You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
-
+			msg = _('Guppy cannot run because the program Puppy is not available. Please install Puppy.')
+			msg += '\n\n' + _('You can download Puppy from') + ' <i>http://sourceforge.net/projects/puppy</i>'
+			dialog.set_markup(msg)
 			response = dialog.run()
 			dialog.destroy()
 			return
@@ -451,17 +472,20 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 		col.set_sort_order(order)
 		data[0].set_sort_column_id(data[1], order)
 
-	def on_delete_btn_clicked(self, widget, treeview, fs_model):
+	def on_delete_btn_clicked(self, widget, treeview, fs_model, warn=True):
 		selection = treeview.get_selection()
 		model, rows = selection.get_selected_rows()
 		
+		if len(rows) == 0:
+			return
+		
 		files = []
 		for path in rows:
 			iter = model.get_iter(path)
 			name = model.get_value(iter, FileSystemModel.NAME_COL)
 			files.append(name)
 			
-		self.deleteFiles(files, fs_model)
+		self.deleteFiles(files, fs_model, warn)
 			
 	def on_download_btn_clicked(self, widget, data=None):
 		self.transferFile('download')
@@ -478,24 +502,19 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 			if widget.handler_is_connected(handler_id):
 				widget.disconnect(handler_id)
 
-	def on_goto_pc_dir(self, widget, data=None):
-		if self.pc_path_bar:
-			self.pc_path_bar.hide()		
-			self.pc_path_entry_box.show()
-		self.pc_path_entry.grab_focus()
-
-	def on_goto_pvr_dir(self, widget, data=None):		
-		if self.pvr_path_bar:
-			self.pvr_path_bar.hide()		
-			self.pvr_path_entry_box.show()
-		self.pvr_path_entry.grab_focus()
+	def on_goto_dir(self, widget, path, fs_model):
+		if path['bar']:
+			path['bar'].hide()
+			path['entry'].set_text(fs_model.getCWD())
+			path['entry_box'].show()
+		path['entry'].grab_focus()
 
 	def on_mkdir_btn_clicked(self, widget, treeview, fs_model):
 		try:
 			name = fs_model.mkdir()
 		except OSError:
 			msg = '<b>' + _('Error while creating folder.') + '</b>\n\n'
-			msg += _('Can not create folder because you do not have permission to write in its parent folder.')
+			msg += _('Cannot create folder because you do not have permission to write in its parent folder.')
 			dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR, buttons=gtk.BUTTONS_CLOSE)
 			dialog.set_markup(msg)
 			response = dialog.run()
@@ -550,7 +569,7 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 					msg += _('because you do not have permissions to change it or its parent folder.')
 					dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR)
 					dialog.set_markup(msg)
-					dialog.add_buttons( _('Skip'), SKIP, _('Retry'), RETRY)
+					dialog.add_buttons( _('_Skip'), SKIP, _('_Retry'), RETRY)
 					response = dialog.run()
 					dialog.destroy()
 		
@@ -568,7 +587,7 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 					msg += _('is already used in this folder.')
 					dialog = gtk.MessageDialog(type=gtk.MESSAGE_ERROR)
 					dialog.set_markup(msg)
-					dialog.add_buttons( _('Cancel'), CANCEL,_('Replace'), REPLACE)
+					dialog.add_buttons( _('Cancel'), CANCEL,_('_Replace'), REPLACE)
 					response = dialog.run()
 					dialog.destroy()
 		
@@ -576,7 +595,7 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 					if response == CANCEL or response == gtk.RESPONSE_DELETE_EVENT:
 						break
 		
-					deleted = self.deleteFiles([new_name], fs_model)
+					deleted = self.deleteFiles([new_name], fs_model, False)
 					
 					if not deleted:
 						break
@@ -602,19 +621,26 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 		if fs_model == self.pc_model:
 			self.updateFreeSpace(self.pc_model)
 			if self.no_path_bar_support == False:
-				self.pc_path_entry_box.hide()
+				self.pc_path['entry_box'].hide()
 				if dir_changed:
-					self.pc_path_bar.setPath(path)
-				self.pc_path_bar.show()
+					self.pc_path['bar'].setPath(path)
+				self.pc_path['bar'].show()
 		else:
 			if self.no_path_bar_support == False:
-				self.pvr_path_entry_box.hide()
+				self.pvr_path['entry_box'].hide()
 				if dir_changed:
-					self.pvr_path_bar.setPath(path)
-				self.pvr_path_bar.show()
-		
+					self.pvr_path['bar'].setPath(path)
+				self.pvr_path['bar'].show()
+
+	def on_path_entry_key_press(self, entry, event, path):
+		keyname = gtk.gdk.keyval_name(event.keyval)
+		# <ESC>: Hide path entry
+		if keyname == 'Escape':
+			if self.no_path_bar_support == False:
+				path['entry_box'].hide()
+				path['bar'].show()
+				
 	def on_pvr_error_btn_clicked(self, widget, data=None):
-		# TODO: Open error dialog
 		self.pvr_error_window.show()
 		widget.hide()
 	
@@ -661,6 +687,10 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 		selection = treeview.get_selection()
 		model, files = selection.get_selected_rows()
 		
+		# Only a single file can be renamed at a time.
+		if len(files) != 1:
+			return
+		
 		path = files[0]
 		iter = model.get_iter(path)
 		col = treeview.get_column(0)
@@ -752,16 +782,16 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 			actiongrp.set_sensitive(False)
 
 	def on_treeview_key_press(self, treeview, event, fs_model):
-		
+		keyname = gtk.gdk.keyval_name(event.keyval)
 		# <F2>: Rename selected file.
-		if event.keyval == 65471:
-			selection = treeview.get_selection()
-			model, files = selection.get_selected_rows()
-			if len(files) == 1:
-				self.on_rename_btn_clicked(None, treeview, fs_model)
+		if keyname == 'F2':
+			self.on_rename_btn_clicked(None, treeview, fs_model)
 		# <Delete>: Delete selected files.
-		elif event.keyval == 65535:
-			self.on_delete_btn_clicked(None, treeview, fs_model)
+		elif keyname == 'Delete':
+			warn = True
+			if event.get_state() & gtk.gdk.SHIFT_MASK:
+				warn = False
+			self.on_delete_btn_clicked(None, treeview, fs_model, warn)
 	
 	def on_treeview_row_activated(self, widget, path, col, fs_model):
 		model = widget.get_model()
@@ -774,17 +804,29 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 			path = fs_model.getCWD()
 			if fs_model == self.pc_model:
 				if self.no_path_bar_support == False:
-					self.pc_path_entry_box.hide()
-					self.pc_path_bar.setPath(path)
-					self.pc_path_bar.show()
-				self.pc_path_entry.set_text(path)
+					self.pc_path['entry_box'].hide()
+					self.pc_path['bar'].setPath(path)
+					self.pc_path['bar'].show()
+				self.pc_path['entry'].set_text(path)
 				self.updateFreeSpace(self.pc_model)
 			else:
 				if self.no_path_bar_support == False:
-					self.pvr_path_entry_box.hide()
-					self.pvr_path_bar.setPath(path)
-					self.pvr_path_bar.show()
-				self.pvr_path_entry.set_text(path)
+					self.pvr_path['entry_box'].hide()
+					self.pvr_path['bar'].setPath(path)
+					self.pvr_path['bar'].show()
+				self.pvr_path['entry'].set_text(path)
+
+	def on_transfer_cancel_btn_clicked(self, widget, file_transfer):
+		state = widget.get_data('state')
+		if state == 'remove':
+			file_transfer.cancel()
+			
+			progress_box = file_transfer.xml.get_widget('progress_box')
+			progress_box.destroy()
+		elif state == 'stop':
+			if file_transfer == self.last_file_transfer:
+				self.last_file_transfer.setQuitAfterTransfer(False)
+			self.puppy.cancelTransfer()
 			
 	def on_transfer_clear_btn_clicked(self, widget, data=None):
 		# Loop until we get a Queue.Empty exception
@@ -802,23 +844,11 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 	def on_transfer_close_btn_clicked(self, widget, data=None):
 		self.show_file_transfer_action.set_active(False)
 
-	def on_transfer_remove_btn_clicked(self, widget, file_transfer):
-		file_transfer.cancel()
-		
-		progress_box = file_transfer.xml.get_widget('progress_box')
-		progress_box.destroy()
-
-	def on_transfer_stop_btn_clicked(self, widget, file_transfer):
-		# Don't quit if user explicitly stopped the transfer the last transfer
-		if file_transfer == self.last_file_transfer:
-			self.last_file_transfer.setQuitAfterTransfer(False)
-		self.puppy.cancelTransfer()
-
 	def on_turbo_toggled(self, widget, data=None):
 		self.turbo = widget.get_active()
 		
 		if self.turbo and self.turbo_warn:
-			dialog = gtk.MessageDialog(message_format=_('You can not use your PVR remote control when Turbo mode is on.'),
+			dialog = gtk.MessageDialog(message_format=_('You cannot use your PVR remote control when Turbo mode is on.'),
 			                           type=gtk.MESSAGE_WARNING,
 			                           buttons=gtk.BUTTONS_CLOSE)
 
@@ -898,7 +928,11 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 			else:
 				msg += ' ' + _('PVR')
 			msg += '.\n'
-			msg += _('Do you still want to continue transfer?')	
+			msg += _('Do you still want to continue your')
+			if direction == 'download':
+				msg += ' ' + _('download?')
+			else:
+				msg += ' ' + _('upload?')
 			
 			dialog = gtk.MessageDialog(type=gtk.MESSAGE_QUESTION,
 			                           buttons=gtk.BUTTONS_YES_NO,
@@ -952,11 +986,10 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 			                             date, xml)
 
 			# Connect transfer instance remove button signal handler
-			remove_btn = xml.get_widget('transfer_remove_button')
-			remove_btn.connect('clicked', self.on_transfer_remove_btn_clicked, file_transfer)
-			stop_btn = xml.get_widget('transfer_stop_button')
-			stop_btn.connect('clicked', self.on_transfer_stop_btn_clicked, file_transfer)
-
+			cancel_btn = xml.get_widget('transfer_cancel_button')
+			cancel_btn.connect('clicked', self.on_transfer_cancel_btn_clicked, file_transfer)
+			cancel_btn.set_data('state', 'remove')
+			
 			if file_exists:
 				existing_files.append(file_transfer)
 			else:
@@ -971,14 +1004,14 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 		for file in existing_files:
 			if replace_all == False:
 				SKIP, REPLACE, REPLACE_ALL = range(3)
-				msg = _('The file') + ' "' + file.dst + '" ' + _('already exists. Would you like to replace it?')
+				msg = _('The file "%s" already exists. Would you like to replace it?') % file.dst
 				msg2 = _('If you replace an existing file, its contents will be overwritten.')
 				dialog = gtk.MessageDialog(type=gtk.MESSAGE_QUESTION,
 				                           message_format=msg)
 				                           
 				if len(existing_files) > 1:
-					dialog.add_button(_('Replace All'), REPLACE_ALL)
-				dialog.add_buttons( _('Skip'), SKIP, _('Replace'), REPLACE)
+					dialog.add_button(_('Replace _All'), REPLACE_ALL)
+				dialog.add_buttons( _('_Skip'), SKIP, _('_Replace'), REPLACE)
 				response = dialog.run()
 				dialog.destroy()
 	
@@ -1028,9 +1061,9 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 			return
 			
 		if fs_model == self.pvr_model:
-			self.pvr_path_bar.setPath(fs_model.getCWD())
+			self.pvr_path['bar'].setPath(fs_model.getCWD())
 		else:
-			self.pc_path_bar.setPath(fs_model.getCWD())
+			self.pc_path['bar'].setPath(fs_model.getCWD())
 	
 	def updateScreenInfo(self):
 		try:
@@ -1080,12 +1113,16 @@ You can download Puppy from <i>http://sourceforge.net/projects/puppy</i>'''))
 					pass
 
 			model.changeDir()
-			selection.handler_unblock(handler_id)
 			
 			# Reselect rows
 			for path in selected_rows[1]:
 				selection.select_path(path)
 
+			# Call signal handler explicitly because it will not be called if no
+			# rows are reselected, i.e. not paths in selected_rows[] are valid.
+			self.on_treeview_changed(selection, model)
+			
+			selection.handler_unblock(handler_id)
 
 class PVRErrorWindow:
 	ICON_COL, ICON_SIZE_COL, MSG_COL, OUTPUT_COL = range(4)
@@ -1225,20 +1262,13 @@ class TransferThread(threading.Thread):
 				widget.set_sensitive(True)
 				gtk.gdk.threads_leave()
 		
-			remove_btn = xml.get_widget('transfer_remove_button')	
-			gtk.gdk.threads_enter()
-			remove_btn.hide()
-			gtk.gdk.threads_leave()
-			
-			stop_btn = xml.get_widget('transfer_stop_button')	
-			gtk.gdk.threads_enter()
-			stop_btn.show()
-			gtk.gdk.threads_leave()
+			cancel_btn = xml.get_widget('transfer_cancel_button')	
 
-			# Set width of Stop button to be the same as Remove button
 			gtk.gdk.threads_enter()
-			allocation = remove_btn.get_allocation()
-			stop_btn.set_size_request(allocation.width, allocation.height)
+			allocation = cancel_btn.get_allocation()
+			cancel_btn.set_label(gtk.STOCK_STOP)
+			cancel_btn.set_size_request(allocation.width, allocation.height)
+			cancel_btn.set_data('state', 'stop')
 			gtk.gdk.threads_leave()
 
 			progress_bar = xml.get_widget('transfer_progressbar')
@@ -1294,12 +1324,9 @@ class TransferThread(threading.Thread):
 				gtk.gdk.threads_enter()
 				progress_bar.set_fraction(float(percent)/100)
 				progress_bar.set_text('(' + transfer_time['remaining'] + ' ' + _('Remaining') + ')')
-
-				while gtk.events_pending():
-					gtk.main_iteration()
 				gtk.gdk.threads_leave()
 
-			# Disable turbo mode. The PVR remote control can not be used if
+			# Disable turbo mode. The PVR remote control cannot be used if
 			# turbo mode is left on.
 			if self.guppy.turbo == True:
 				self.guppy.puppy.setTurbo(False)
@@ -1328,7 +1355,7 @@ class TransferThread(threading.Thread):
 				if direction == 'download':
 					msg = _('Failed to download:') + '\n' + src_file
 				else:
-					msg = _('Failed to upload: ') + '\n' + src_file
+					msg = _('Failed to upload:') + '\n' + src_file
 
 				self.guppy.pvr_error_window.addError(msg, transfer_error)
 
@@ -1342,10 +1369,10 @@ class TransferThread(threading.Thread):
 				widget.set_sensitive(False)
 				gtk.gdk.threads_leave()
 
-			# Swap Stop button for Remove button
+			# Change Stop button to Remove button
 			gtk.gdk.threads_enter()
-			stop_btn.hide()
-			remove_btn.show()
+			cancel_btn.set_data('state', 'remove')
+			cancel_btn.set_label(gtk.STOCK_REMOVE)
 			gtk.gdk.threads_leave()
 
 			file_transfer.complete()
@@ -1596,10 +1623,10 @@ class PathBar(gtk.Container):
 		if self.fs == 'pvr':
 			path = path.replace('/', '\\')
 			self.guppy.pvr_model.changeDir(path)
-			self.guppy.pvr_path_entry.set_text(path)
+			self.guppy.pvr_path['entry'].set_text(path)
 		else:
 			self.guppy.pc_model.changeDir(path)
-			self.guppy.pc_path_entry.set_text(path)
+			self.guppy.pc_path['entry'].set_text(path)
 
 	def on_down_btn_clicked(self, btn):
 		self.queue_resize()
@@ -1647,7 +1674,7 @@ class PathBar(gtk.Container):
 				break
 		self.first_scrolled_btn = i + 1
 		
-	def setPath(self, path):
+	def setPath(self, path, update_btns=True):
 		path = path.replace('\\', '/')
 		path = os.path.normpath(path)
 		# os.path.normpath() doesn't normalise '//' to '/'
@@ -1655,7 +1682,7 @@ class PathBar(gtk.Container):
 			path = '/'
 		
 		# Check if we are changing to a dir on the same path
-		if self.updatePathBtns(path):
+		if update_btns and self.updatePathBtns(path):
 			return
 		
 		self.path = path
