@@ -1,5 +1,5 @@
 ## about.py - Information about Guppy
-## Copyright (C) 2005 Tony Tsui <tsui.tony@gmail.com>
+## Copyright (C) 2005-2006 Tony Tsui <tsui.tony@gmail.com>
 ##
 ## This program is free software; you can redistribute it and/or modify
 ## it under the terms of the GNU General Public License as published by
@@ -16,12 +16,17 @@
 ## Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 
 APP_NAME = 'Guppy'
-VERSION = '0.0.91'
+VERSION = '0.0.92'
 DESCRIPTION='Topfield PVR File Downloader'
 AUTHOR = 'Tony Tsui'
 AUTHOR_EMAIL = 'tsui.tony@gmail.com'
 # List of additional contributors. Format: 'Name Email'
-CONTRIBUTORS = [ 'Tango Desktop Project http://tango-project.org' ]
+CONTRIBUTORS = [ 'Icons by:', 
+                 'Tango Desktop Project http://tango-project.org',
+                 'Peter Appleyard',
+					  'Translations by:',
+                 'Jürgen Bausa',
+]
 WEBSITE = 'http://guppy.nongnu.org'
 COPYRIGHT = 'Copyright (C) 2005-2006 Tony Tsui'
 LICENSE = 'GNU Public License & CC-by-SA 2.5 License'
